@@ -1,12 +1,14 @@
 # log.py
 
-import colorlog
 import logging
+
+import colorlog
 from tabulate import tabulate
+
 from terralab.constants import FAILED_KEY, SUCCEEDED_KEY, RUNNING_KEY, PREPARING_KEY
 
 
-def configure_logging(debug: bool):
+def configure_logging(debug: bool) -> None:
     log_level = logging.DEBUG if debug else logging.INFO
 
     handler = colorlog.StreamHandler()
@@ -26,20 +28,20 @@ def configure_logging(debug: bool):
     logging.basicConfig(level=log_level, handlers=[handler])
 
 
-def indented(string_to_indent: str, n_spaces: int = 2):
+def indented(string_to_indent: str, n_spaces: int = 2) -> str:
     return f"{' ' * n_spaces}{string_to_indent}"
 
 
-def join_lines(list_of_strings: list[str]):
+def join_lines(list_of_strings: list[str]) -> str:
     return "\n".join(list_of_strings)
 
 
-def pad_column(first_string: str, column_width: int = 20):
+def pad_column(first_string: str, column_width: int = 20) -> str:
     column_width = max(column_width, len(first_string) + 1)
     return first_string.ljust(column_width)
 
 
-def add_blankline_before(string: str):
+def add_blankline_before(string: str) -> str:
     return f"\n{string}"
 
 
@@ -75,11 +77,8 @@ def format_table_with_status(
     # find status column index; this raises a ValueError if the status_key is not found
     status_column_index = headers.index(status_key)
     for single_table_row in rows_list:
-        row_without_none = [
-            "" if x is None else x for x in single_table_row
-        ]  # workaround for https://github.com/astanin/python-tabulate/issues/323
         all_table_rows.append(
-            format_status_in_table_row(row_without_none, status_column_index)
+            format_status_in_table_row(single_table_row, status_column_index)
         )
 
     return tabulate(
